pub struct ConfigWriteResult {
pub mmio_remove: Vec<BusRange>,
pub mmio_add: Vec<BusRange>,
pub io_remove: Vec<BusRange>,
pub io_add: Vec<BusRange>,
pub removed_pci_devices: Vec<PciAddress>,
}Expand description
Result of a write to a device’s PCI configuration space. This value represents the state change(s) that occurred due to the write.
Fields
mmio_remove: Vec<BusRange>The BusRange in the vector will be removed from mmio_bus
mmio_add: Vec<BusRange>The BusRange in the vector will be added into mmio_bus
io_remove: Vec<BusRange>The BusRange in the vector will be removed from io_bus
io_add: Vec<BusRange>The BusRange in the vector will be added into io_bus
removed_pci_devices: Vec<PciAddress>Device specified at PciAddress will be removed after this config write
Vec<PciAddress>>: specified device will be removed after this config write