pub enum Error {
UnsupportedPlatform,
CommandError,
ParseError,
}Expand description
An error that could be returned when retrieving device information.
Variants
UnsupportedPlatform
The platform is unsupported.
CommandError
An OS issue has occurred.
ParseError
The result returned properly but could not be parsed.