pub enum HotPlugKey {
HostUpstreamPort {
host_addr: PciAddress,
},
HostDownstreamPort {
host_addr: PciAddress,
},
HostVfio {
host_addr: PciAddress,
},
GuestDevice {
guest_addr: PciAddress,
},
}Expand description
The key to identify hotplug device from host view. like host sysfs path for vfio pci device, host disk file path for virtio block device
Variants
HostUpstreamPort
Fields

host_addr: PciAddressHostDownstreamPort
Fields

host_addr: PciAddressHostVfio
Fields

host_addr: PciAddressGuestDevice
Fields

guest_addr: PciAddressTrait Implementations
Sourceimpl Clone for HotPlugKey
impl Clone for HotPlugKey
Sourcefn clone(&self) -> HotPlugKey
fn clone(&self) -> HotPlugKey
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for HotPlugKey
impl Debug for HotPlugKey
Sourceimpl Hash for HotPlugKey
impl Hash for HotPlugKey
Sourceimpl PartialEq for HotPlugKey
impl PartialEq for HotPlugKey
impl Copy for HotPlugKey
impl Eq for HotPlugKey
impl StructuralPartialEq for HotPlugKey