Enum VectorReg

#[repr(usize)]
enum VectorReg { Isr = 256, Tmr = 384, Irr = 512, }
The APIC registers that store interrupt vector bitmaps. Each has 256 bit flags, one for each interrupt vector. The flags are spread across the first 32 bits of each of eight 16-byte APIC register slots.

Variants



Isr = 256

In-service register. A bit is set for each interrupt vector currently being serviced by the processor.



Tmr = 384

Trigger mode register. Records whether interrupts are edge-triggered (bit is clear) or level-triggered (bit is set).



Irr = 512

Interrupt request register. A bit is set for each interrupt vector received by the APIC but not yet serviced by the processor.