Struct PendingInterrupts

pub struct PendingInterrupts {
    pub fixed: Option<Vector>,
    pub nmis: u32,
    pub init: bool,
    pub startup: Option<Vector>,
    pub needs_window: bool,
}
Pending Apic interrupts to be injected into a vcpu.

Fields

fixed: Option<Vector>

Vector of a pending fixed interrupt.

nmis: u32

Number of pending non-maskable interrupts.

init: bool

True if there is a pending INIT IPI.

startup: Option<Vector>

Vector of a pending startup IPI (SIPI).

needs_window: bool

True if there are additional pending interrupts to delivered in the future, so an interrupt window should be requested for the vcpu.