pub(super) struct DelayedIoApicIrqEvents {
pub events: Vec<usize>,
pub trigger: Event,
}Fields
events: Vec<usize>Vec of ioapic irq events that have been delayed because the ioapic was locked when service_irq was called on the irqchip.
trigger: EventEvent which is meant to trigger process of any irqs events that were delayed.
Implementations