pub struct StaticRegister<T>where
T: RegisterValue,{
spec: &'static StaticRegisterSpec<T>,
}Expand description
A static register is a register inited by hardware. The value won’t change in it’s lifetime. All functions implemented on this one is thread safe.
Fields
spec: &'static StaticRegisterSpec<T>Implementations
Sourceimpl<T> StaticRegister<T>where
T: RegisterValue,
impl<T> StaticRegister<T>where
T: RegisterValue,
Sourcepub fn new(spec: &'static StaticRegisterSpec<T>) -> StaticRegister<T>
pub fn new(spec: &'static StaticRegisterSpec<T>) -> StaticRegister<T>
Create an new static register from spec.