Struct VtpmProxy

pub struct VtpmProxy {
    dbus_connection: Option<Connection>,
    buf: Vec<u8>,
}
A proxy object that connects to the vtpmd on ChromeOS.

Fields

dbus_connection: Option<Connection>buf: Vec<u8>

Implementations

Source

impl VtpmProxy

pub fn new() -> Self

Returns a proxy that can be connected to the vtpmd.

fn get_or_create_dbus_connection(&mut self) -> Result<&Connection, Error>

fn try_execute_command(&mut self, command: &[u8]) -> Result<(), Error>