Enum DeviceProvider

pub enum DeviceProvider {
    Created {
        control_tube: Mutex<Tube>,
    },
    Started {
        inner: Arc<ProviderInner>,
    },
    Failed,
}
Device provider is an xhci backend device provider that provides generic semantics to handle various types of backend devices and connects them to the xhci layer.

Variants



Created

Fields

control_tube: Mutex<Tube>


Started

Fields



Failed

Implementations

Source

impl DeviceProvider

pub fn new() -> Result<(Tube, DeviceProvider)>

fn start_helper( &mut self, fail_handle: Arc<dyn FailHandle>, event_loop: Arc<EventLoop>, hub: Arc<UsbHub>, ) -> Result<()>