Struct FidoGuestKey

pub struct FidoGuestKey {
    pub pending_in_packets: VecDeque<[u8; 64]>,
    pub idle: u8,
    pub timer: PollTimer,
}
FidoGuestKey is the struct representation of a virtual fido device as seen by the guest VM. It takes care of bubbling up transactions from the host into the guest and show a representation of the device’s state into the guest.

Fields

pending_in_packets: VecDeque<[u8; 64]>

Queue of packets already processed by the host that need to be sent to the guest.

idle: u8

HID Idle state of the security key.

timer: PollTimer

Timer used to poll to periodically send packets to pending USB transfers.

Implementations

Source

impl FidoGuestKey

pub fn new() -> Result<Self>

pub fn reset(&mut self)

Resets the guest key representation, stopping the poll and clearing the packet queue.

pub fn return_data_to_guest( &mut self, transfer_opt: Option<FidoTransfer>, ) -> Result<Option<FidoTransfer>>

Sends data to the guest by associating a given transfer to the oldest packet in the queue. If the data from the host hasn’t been read yet (the packet queue is empty), it returns the same transfer back to the caller, unmodified.