pub struct FidoTransferHandle {
pub weak_transfer: Weak<Mutex<Option<FidoTransfer>>>,
}Expand description
Implementation of a cancel handler for FidoTransfer
Fields
weak_transfer: Weak<Mutex<Option<FidoTransfer>>>Trait Implementations
Sourceimpl GenericTransferHandle for FidoTransferHandle
impl GenericTransferHandle for FidoTransferHandle
Sourcefn cancel(&self) -> BackendResult<()>
fn cancel(&self) -> BackendResult<()>
All objects that implement this method need to make sure
cancel() is safe to call
multiple times as its invocation should be idempotent. A transfer that has already been
canceled ought not to error if it gets canceled again.Auto Trait Implementations
impl Freeze for FidoTransferHandle
impl RefUnwindSafe for FidoTransferHandle
impl Send for FidoTransferHandle
impl Sync for FidoTransferHandle
impl Unpin for FidoTransferHandle
impl UnwindSafe for FidoTransferHandle