pub(crate) struct UsbUtilEventHandler {
pub device: Arc<Mutex<BackendDeviceType>>,
pub event_loop: Arc<EventLoop>,
pub port: Mutex<Weak<UsbPort>>,
pub self_ref: Mutex<Option<Arc<UsbUtilEventHandler>>>,
}Fields
device: Arc<Mutex<BackendDeviceType>>event_loop: Arc<EventLoop>port: Mutex<Weak<UsbPort>>self_ref: Mutex<Option<Arc<UsbUtilEventHandler>>>Implementations
Sourceimpl UsbUtilEventHandler
impl UsbUtilEventHandler
pub(crate) fn new( device: Arc<Mutex<BackendDeviceType>>, event_loop: Arc<EventLoop>, ) -> Arc<Self>
Sourcepub fn activate(
self: &Arc<Self>,
event_type: EventType,
port: Weak<UsbPort>,
) -> Result<()>
pub fn activate( self: &Arc<Self>, event_type: EventType, port: Weak<UsbPort>, ) -> Result<()>
Register this handler with the event loop. After a successful return, call finalize_detach() for cleanup.
Sourcepub fn signal_detach(&self)
pub fn signal_detach(&self)
Signal this handler to perform the host resource cleanup.
Sourcepub(crate) fn finalize_detach(&self) -> Result<()>
pub(crate) fn finalize_detach(&self) -> Result<()>
Clean up the resources and remove itself from the event loop.