pub struct RingBufferStopCallback {
_inner: Arc<Mutex<RingBufferStopCallbackInner>>,
}Expand description
RingBufferStopCallback wraps a callback. The callback will be invoked when last instance of RingBufferStopCallback and its clones is dropped.
The callback might not be invoked in certain cases. Don’t depend this for safety.
Fields
_inner: Arc<Mutex<RingBufferStopCallbackInner>>Implementations
Sourceimpl RingBufferStopCallback
impl RingBufferStopCallback
Sourcepub fn new<C: 'static + FnMut() + Send>(cb: C) -> RingBufferStopCallback
pub fn new<C: 'static + FnMut() + Send>(cb: C) -> RingBufferStopCallback
Create new callback from closure.