Struct ScatterGatherBuffer

pub struct ScatterGatherBuffer {
    mem: GuestMemory,
    td: TransferDescriptor,
}
See xHCI spec 3.2.8 for scatter/gather transfer. It’s used in bulk/interrupt transfers. See 3.2.10 for details.

Fields

mem: GuestMemorytd: TransferDescriptor

Implementations

Source

impl ScatterGatherBuffer

pub fn new( mem: GuestMemory, td: TransferDescriptor, ) -> Result<ScatterGatherBuffer, Error>

Create a new buffer from transfer descriptor.

pub fn len(&self) -> Result<usize, Error>

Total len of this buffer.

pub fn is_empty(&self) -> Result<bool, Error>

fn get_trb_data( &self, atrb: &AddressedTrb, ) -> Result<(GuestAddress, usize), Error>

Get the guest address and length of the TRB’s data buffer. This is usually a separate buffer pointed to by the TRB, but it can also be within the TRB itself in the case of immediate data.

pub fn read(&self, buffer: &mut [u8]) -> Result<usize, Error>

Read content to buffer, return number of bytes read.

pub fn write(&self, buffer: &[u8]) -> Result<usize, Error>

Write content from buffer, return number of bytes written.