pub struct TransferRingTrbHandler {
mem: GuestMemory,
port: Arc<UsbPort>,
interrupter: Arc<Mutex<Interrupter>>,
slot_id: u8,
endpoint_id: u8,
transfer_manager: XhciTransferManager,
stream_id: Option<u16>,
}Expand description
TransferRingTrbHandler handles trbs on transfer ring.
Fields
mem: GuestMemoryport: Arc<UsbPort>interrupter: Arc<Mutex<Interrupter>>slot_id: u8endpoint_id: u8transfer_manager: XhciTransferManagerstream_id: Option<u16>Trait Implementations
Sourceimpl TransferDescriptorHandler for TransferRingTrbHandler
impl TransferDescriptorHandler for TransferRingTrbHandler
Sourcefn handle_transfer_descriptor(
&self,
descriptor: TransferDescriptor,
trigger_event: Event,
) -> Result<()>
fn handle_transfer_descriptor( &self, descriptor: TransferDescriptor, trigger_event: Event, ) -> Result<()>
Process descriptor asynchronously, signal trigger_event when ready to proceed.
Sourcefn cancel_transfers(&self, callback: RingBufferStopCallback)
fn cancel_transfers(&self, callback: RingBufferStopCallback)
Cancel transfers. This is used to stop the ring activity as soon as possible when we
process a Stop Endpoint command.
xHCI spec 4.6.9 states we need to stop the USB activity for the pipe before sending the
completion event. Use the callback to ensure that all the in-flight transfers are gone
before sending the event, if the backend cannot immediately cancel them.