Struct VfioContainer

pub struct VfioContainer {
    container: File,
    groups: HashMap<u32, Arc<Mutex<VfioGroup>>>,
    iommu_type: Option<IommuType>,
}
VfioContainer contain multi VfioGroup, and delegate an IOMMU domain table

Fields

container: Filegroups: HashMap<u32, Arc<Mutex<VfioGroup>>>iommu_type: Option<IommuType>

Implementations

Source

impl VfioContainer

pub fn new() -> Result<Self, VfioError>

pub fn new_from_container(container: File) -> Result<Self, VfioError>

fn is_group_set(&self, group_id: u32) -> bool

fn check_extension(&self, val: IommuType) -> bool

fn set_iommu(&mut self, val: IommuType) -> i32

fn set_iommu_checked(&mut self, val: IommuType) -> Result<(), VfioError>

pub unsafe fn vfio_dma_map( &self, iova: u64, size: u64, user_addr: u64, write_en: bool, ) -> Result<(), VfioError>

Safety

The caller is responsible for determining the safety of the VFIO_IOMMU_MAP_DMA ioctl.

unsafe fn vfio_iommu_type1_dma_map( &self, iova: u64, size: u64, user_addr: u64, write_en: bool, ) -> Result<(), VfioError>

Safety

The caller is responsible for determining the safety of the VFIO_IOMMU_MAP_DMA ioctl.

pub fn vfio_dma_unmap(&self, iova: u64, size: u64) -> Result<(), VfioError>

fn vfio_iommu_type1_dma_unmap( &self, iova: u64, size: u64, ) -> Result<(), VfioError>

pub fn vfio_get_iommu_page_size_mask(&self) -> Result<u64, VfioError>

fn vfio_iommu_type1_get_iommu_page_size_mask(&self) -> Result<u64, VfioError>

pub fn vfio_iommu_iova_get_iova_ranges( &self, ) -> Result<Vec<AddressRange>, VfioError>

fn vfio_iommu_type1_get_iova_ranges( &self, ) -> Result<Vec<AddressRange>, VfioError>

fn set_iommu_from(&mut self, iommu_dev: IommuDevType) -> Result<(), VfioError>

fn get_group_with_vm( &mut self, id: u32, vm: &dyn Vm, iommu_dev: IommuDevType, ) -> Result<Arc<Mutex<VfioGroup>>, VfioError>

fn get_group(&mut self, id: u32) -> Result<Arc<Mutex<VfioGroup>>, VfioError>

fn remove_group(&mut self, id: u32, reduce: bool)

pub fn clone_as_raw_descriptor(&self) -> Result<RawDescriptor, VfioError>

pub fn group_ids(&self) -> Vec<&u32>