Struct VfioContainerManager

pub struct VfioContainerManager {
    no_iommu_container: Option<Arc<Mutex<VfioContainer>>>,
    iommu_containers: Vec<Arc<Mutex<VfioContainer>>>,
    coiommu_container: Option<Arc<Mutex<VfioContainer>>>,
    pkvm_iommu_container: Option<Arc<Mutex<VfioContainer>>>,
}
A helper struct for managing VFIO containers

Fields

no_iommu_container: Option<Arc<Mutex<VfioContainer>>>

One VFIO container shared by all VFIO devices that don’t attach to any IOMMU device.

iommu_containers: Vec<Arc<Mutex<VfioContainer>>>

For IOMMU enabled devices, all VFIO groups that share the same IOVA space are managed by one VFIO container.

coiommu_container: Option<Arc<Mutex<VfioContainer>>>

One VFIO container shared by all VFIO devices that attach to the CoIOMMU device.

pkvm_iommu_container: Option<Arc<Mutex<VfioContainer>>>

One VFIO container shared by all VFIO devices that attach to pKVM.

Implementations

Source

impl VfioContainerManager

pub fn new() -> Self

pub fn get_container<P: AsRef<Path>>( &mut self, iommu_type: IommuDevType, sysfspath: Option<P>, ) -> Result<Arc<Mutex<VfioContainer>>, VfioError>

The single place to create a VFIO container for a PCI endpoint.

The policy to determine whether an individual or a shared VFIO container will be created for this device is governed by the physical PCI topology, and the argument iommu_type.

Arguments
  • sysfspath - the path to the PCI device, e.g. /sys/bus/pci/devices/0000:02:00.0
  • iommu_type - which type of IOMMU is enabled on this device