struct DiskState {
disk_image: Box<dyn AsyncDisk>,
read_only: bool,
sparse: bool,
id: [u8; 20],
worker_shared_state: Arc<RwLock<WorkerSharedState>>,
}Expand description
Tracks the state of an anynchronous disk.
Fields
disk_image: Box<dyn AsyncDisk>read_only: boolsparse: boolid: [u8; 20]A DiskState is owned by each worker’s executor and cannot be shared by workers, thus
worker_shared_state holds the state shared by workers in Arc.