pub struct DiskOption {Show 13 fields
pub path: PathBuf,
pub read_only: bool,
pub root: bool,
pub sparse: bool,
pub direct: bool,
pub lock: bool,
pub block_size: u32,
pub id: Option<[u8; 20]>,
pub multiple_workers: bool,
pub async_executor: Option<ExecutorKind>,
pub packed_queue: bool,
pub bootindex: Option<usize>,
pub pci_address: Option<PciAddress>,
}Fields
path: PathBufread_only: boolroot: boolWhether this disk should be the root device. Can only be set once. Only useful for adding specific command-line options.
sparse: booldirect: boollock: boolWhether to lock the disk files. Uses flock on Unix and FILE_SHARE_* flags on Windows.
block_size: u32id: Option<[u8; 20]>multiple_workers: boolExperimental option to run multiple worker threads in parallel. If false, only single thread runs by default. Note this option is not effective for vhost-user blk device.
async_executor: Option<ExecutorKind>The async executor kind to simulate the block device with. This option takes precedence over the async executor kind specified by the subcommand’s option. If None, the default or the specified by the subcommand’s option would be used.
packed_queue: boolbootindex: Option<usize>Specify the boot index for this device that the BIOS will use when attempting to boot from bootable devices. For example, if bootindex=2, then the BIOS will attempt to boot from the device right after booting from the device with bootindex=1 fails.
pci_address: Option<PciAddress>Specify PCI address will be used to attach this device
Implementations