pub enum DeviceType {
Show 23 variants
Net,
Block,
Console,
Rng,
Balloon,
Scsi,
P9,
Gpu,
Input,
Vsock,
Iommu,
Sound,
Fs,
Pmem,
Mac80211HwSim,
VideoEncoder,
VideoDecoder,
Scmi,
Wl,
Tpm,
Pvclock,
Media,
VendorDevice(u32),
}Variants
Net
Block
Console
Rng
Balloon
Scsi
P9
Gpu
Input
Vsock
Iommu
Sound
Fs
Pmem
Mac80211HwSim
VideoEncoder
VideoDecoder
Scmi
Wl
Tpm
Pvclock
Media
VendorDevice(u32)
Implementations
Sourceimpl DeviceType
impl DeviceType
Sourcefn virtio_id(&self) -> u32
fn virtio_id(&self) -> u32
Maps a DeviceType to its virtio ID.
DeviceType cannot be cast directly to a numeric type with ‘as u32’ because of VendorDevice.
Sourcepub fn min_queues(&self) -> usize
pub fn min_queues(&self) -> usize
Returns the minimum number of queues that a device of the corresponding type must support.
Note that this does not mean a driver must activate these queues, only that they must be implemented by a spec-compliant device.