Enum StoppedWorker

pub(crate) enum StoppedWorker<Q> {
    WithQueues(Box<Q>),
    AlreadyStopped,
    MissingQueues,
}
When we request to stop the worker, this represents the terminal state for the thread (if it exists).

Variants



WithQueues(Box<Q>)

Worker stopped successfully & returned its queues.



AlreadyStopped

Worker wasn’t running when the stop was requested.



MissingQueues

Worker was running but did not successfully return its queues. Something has gone wrong (and will be in the error log). In the case of a device reset this is fine since the next activation will replace the queues.