pub enum AccessLevel {
None,
Traverse,
Full,
}Expand description
Represents the access level for a path in the allowlist.
Variants
None
No access allowed.
Traverse
Directory traversal (lookup) only access. Automatically granted to ancestor directories of allowed paths to act as a traversable pathway. This level is only granted automatically and cannot be configured manually.
Full
Full read and write access. Granted to explicitly allowed paths and inherited by all their descendants.