Struct CasefoldCache

struct CasefoldCache(BTreeMap<Vec<u8>, CString>);
Per-directory cache for PassthroughFs::ascii_casefold_lookup().

The key of the underlying BTreeMap is a lower-cased file name in the direcoty. The value is the case-sensitive file name stored in the host file system. We assume that if PassthroughFs has exclusive access to the filesystem, this cache exhaustively covers all file names that exist within the directory. So every PassthroughFs’s handler that adds or removes files in the directory is expected to update this cache.

Tuple Fields

0: BTreeMap<Vec<u8>, CString>

Implementations

Source

impl CasefoldCache

fn new(dir: &InodeData) -> Result<Self>

fn insert(&mut self, name: &CStr)

fn lookup(&self, name: &[u8]) -> Option<CString>

fn remove(&mut self, name: &CStr)