Struct OpenedFile

struct OpenedFile {
    file: Option<File>,
    open_flags: c_int,
}

Fields

file: Option<File>open_flags: c_int

Implementations

Source

impl OpenedFile

fn new(file: File, open_flags: c_int) -> Self

fn file(&self) -> &File

fn file_mut(&mut self) -> &mut File

fn leak_fd(&mut self)

Leaks the file descriptor and makes the struct unusable.

This is an optimization to speed up dropping OpenedFile instances, which is useful during an abrupt shutdown. Instead of properly closing the file descriptor, which involves a syscall, this function effectively forgets the file descriptor, relying on the OS to clean it up when the process terminates.