pub enum GpuCommand {
Show 26 variants
GetDisplayInfo(virtio_gpu_ctrl_hdr),
ResourceCreate2d(virtio_gpu_resource_create_2d),
ResourceUnref(virtio_gpu_resource_unref),
SetScanout(virtio_gpu_set_scanout),
SetScanoutBlob(virtio_gpu_set_scanout_blob),
ResourceFlush(virtio_gpu_resource_flush),
TransferToHost2d(virtio_gpu_transfer_to_host_2d),
ResourceAttachBacking(virtio_gpu_resource_attach_backing),
ResourceDetachBacking(virtio_gpu_resource_detach_backing),
GetCapsetInfo(virtio_gpu_get_capset_info),
GetCapset(virtio_gpu_get_capset),
GetEdid(virtio_gpu_get_edid),
CtxCreate(virtio_gpu_ctx_create),
CtxDestroy(virtio_gpu_ctx_destroy),
CtxAttachResource(virtio_gpu_ctx_resource),
CtxDetachResource(virtio_gpu_ctx_resource),
ResourceCreate3d(virtio_gpu_resource_create_3d),
TransferToHost3d(virtio_gpu_transfer_host_3d),
TransferFromHost3d(virtio_gpu_transfer_host_3d),
CmdSubmit3d(virtio_gpu_cmd_submit),
ResourceCreateBlob(virtio_gpu_resource_create_blob),
ResourceMapBlob(virtio_gpu_resource_map_blob),
ResourceUnmapBlob(virtio_gpu_resource_unmap_blob),
UpdateCursor(virtio_gpu_update_cursor),
MoveCursor(virtio_gpu_update_cursor),
ResourceAssignUuid(virtio_gpu_resource_assign_uuid),
}Expand description
A virtio gpu command and associated metadata specific to each command.
Variants
GetDisplayInfo(virtio_gpu_ctrl_hdr)
ResourceCreate2d(virtio_gpu_resource_create_2d)
ResourceUnref(virtio_gpu_resource_unref)
SetScanout(virtio_gpu_set_scanout)
SetScanoutBlob(virtio_gpu_set_scanout_blob)
ResourceFlush(virtio_gpu_resource_flush)
TransferToHost2d(virtio_gpu_transfer_to_host_2d)
ResourceAttachBacking(virtio_gpu_resource_attach_backing)
ResourceDetachBacking(virtio_gpu_resource_detach_backing)
GetCapsetInfo(virtio_gpu_get_capset_info)
GetCapset(virtio_gpu_get_capset)
GetEdid(virtio_gpu_get_edid)
CtxCreate(virtio_gpu_ctx_create)
CtxDestroy(virtio_gpu_ctx_destroy)
CtxAttachResource(virtio_gpu_ctx_resource)
CtxDetachResource(virtio_gpu_ctx_resource)
ResourceCreate3d(virtio_gpu_resource_create_3d)
TransferToHost3d(virtio_gpu_transfer_host_3d)
TransferFromHost3d(virtio_gpu_transfer_host_3d)
CmdSubmit3d(virtio_gpu_cmd_submit)
ResourceCreateBlob(virtio_gpu_resource_create_blob)
ResourceMapBlob(virtio_gpu_resource_map_blob)
ResourceUnmapBlob(virtio_gpu_resource_unmap_blob)
UpdateCursor(virtio_gpu_update_cursor)
MoveCursor(virtio_gpu_update_cursor)
ResourceAssignUuid(virtio_gpu_resource_assign_uuid)
Implementations
Sourceimpl GpuCommand
impl GpuCommand
Sourcepub fn decode(cmd: &mut Reader) -> Result<GpuCommand, GpuCommandDecodeError>
pub fn decode(cmd: &mut Reader) -> Result<GpuCommand, GpuCommandDecodeError>
Decodes a command from the given chunk of memory.
Sourcepub fn ctrl_hdr(&self) -> &virtio_gpu_ctrl_hdr
pub fn ctrl_hdr(&self) -> &virtio_gpu_ctrl_hdr
Gets the generic virtio_gpu_ctrl_hdr from this command.