pub struct Frontend {
fence_state: Arc<Mutex<FenceState>>,
virtio_gpu: VirtioGpu,
}Fields
fence_state: Arc<Mutex<FenceState>>virtio_gpu: VirtioGpuImplementations
Sourceimpl Frontend
impl Frontend
fn new(virtio_gpu: VirtioGpu, fence_state: Arc<Mutex<FenceState>>) -> Frontend
Sourcepub fn display(&mut self) -> &Rc<RefCell<GpuDisplay>>
pub fn display(&mut self) -> &Rc<RefCell<GpuDisplay>>
Returns the internal connection to the compositor and its associated state.
Sourcepub fn process_display(&mut self) -> ProcessDisplayResult
pub fn process_display(&mut self) -> ProcessDisplayResult
Processes the internal display events and returns true if any display was closed.
Sourcepub fn process_resource_bridge(&mut self, resource_bridge: &Tube) -> Result<()>
pub fn process_resource_bridge(&mut self, resource_bridge: &Tube) -> Result<()>
Processes incoming requests on resource_bridge.
Sourcepub fn process_gpu_control_command(
&mut self,
cmd: GpuControlCommand,
) -> GpuControlResult
pub fn process_gpu_control_command( &mut self, cmd: GpuControlCommand, ) -> GpuControlResult
Processes the GPU control command and returns the result with a bool indicating if the GPU device’s config needs to be updated.
fn process_gpu_command( &mut self, mem: &GuestMemory, cmd: GpuCommand, reader: &mut Reader, ) -> Result<GpuResponse, GpuResponse>
Sourcepub fn process_queue(
&mut self,
mem: &GuestMemory,
queue: &dyn QueueReader,
) -> bool
pub fn process_queue( &mut self, mem: &GuestMemory, queue: &dyn QueueReader, ) -> bool
Processes virtio messages on queue.
fn process_descriptor( &mut self, mem: &GuestMemory, desc_chain: DescriptorChain, ) -> Option<ReturnDescriptor>
pub fn event_poll(&self)