Struct ResourceBridges

struct ResourceBridges {
    resource_bridges: Vec<Tube>,
    should_process: Vec<bool>,
}
This struct takes the ownership of resource bridges and tracks which ones should be processed.

Fields

resource_bridges: Vec<Tube>should_process: Vec<bool>

Implementations

Source

impl ResourceBridges

pub fn new(resource_bridges: Vec<Tube>) -> Self

pub fn append_raw_descriptors(&self, rds: &mut Vec<RawDescriptor>)

pub fn add_to_wait_context(&self, wait_ctx: &mut WaitContext<WorkerToken>)

Adds all resource bridges to WaitContext.

pub fn set_should_process(&mut self, index: usize)

Marks that the resource bridge at the given index should be processed when process_resource_bridges() is called.

pub fn process_resource_bridges( &mut self, state: &mut Frontend, wait_ctx: &mut WaitContext<WorkerToken>, )

Processes all resource bridges that have been marked as should be processed. The markings will be cleared before returning. Faulty resource bridges will be removed from WaitContext.

fn reset_should_process(&mut self)