Struct IpcMemoryMapper

pub struct IpcMemoryMapper {
    request_tx: Tube,
    response_rx: Tube,
    endpoint_id: u32,
}
Sends an addr translation request to another process using Tube, and gets the translated addr from another Tube

Fields

request_tx: Tuberesponse_rx: Tubeendpoint_id: u32

Implementations

Source

impl IpcMemoryMapper

pub fn new(request_tx: Tube, response_rx: Tube, endpoint_id: u32) -> Self

Returns a new IpcMemoryMapper instance.

Arguments
  • request_tx - A tube to send TranslateRequest to another process.
  • response_rx - A tube to receive Option<Vec<MemRegion>>
  • endpoint_id - For the remote iommu to identify the device/ipc mapper.
fn do_request(&self, req: IommuRequest) -> Result<IommuResponse>

pub fn export(&mut self, iova: u64, size: u64) -> Result<Vec<MemRegion>>

pub fn release(&mut self, iova: u64, size: u64) -> Result<()>

pub fn start_export_session(&mut self) -> Result<Event>