Struct ArcedMemoryMapper

struct ArcedMemoryMapper(Arc<Mutex<Box<dyn SharedMemoryMapper>>>);
A SharedMemoryMapper behind an Arc, allowing it to be shared.

This is required by the fact that devices can be activated several times, but the mapper is only provided once. This might be a defect of the VirtioDevice interface.

Tuple Fields

0: Arc<Mutex<Box<dyn SharedMemoryMapper>>>