struct EventQueue(Queue);Expand description
Structure supporting the implementation of VirtioMediaEventQueue for sending events to the
driver.
Tuple Fields
0: QueueTrait Implementations
Sourceimpl VirtioMediaEventQueue for EventQueue
impl VirtioMediaEventQueue for EventQueue
Sourcefn send_event(&mut self, event: V4l2Event)
fn send_event(&mut self, event: V4l2Event)
Wait until an event descriptor becomes available and send event to the guest.
fn send_error(&mut self, session_id: u32, errno: i32)
fn send_error(&mut self, session_id: u32, errno: i32)
Wait until an event descriptor becomes available and send
errno as an error event to the
guest.Auto Trait Implementations
impl Freeze for EventQueue
impl !RefUnwindSafe for EventQueue
impl Send for EventQueue
impl Sync for EventQueue
impl Unpin for EventQueue
impl !UnwindSafe for EventQueue