pub enum NetError {
Show 23 variants
CloneKillEvent(Error),
CreateKillEvent(Error),
CreateWaitContext(Error),
EventAddTap(Error),
EventRemoveTap(Error),
InvalidCmd,
ReadCtrlData(Error),
ReadCtrlHeader(Error),
RxDescriptorsExhausted,
TapEnable(Error),
TapGetMtu(Error),
TapOpen(Error),
TapSetIp(Error),
TapSetMacAddress(Error),
TapSetNetmask(Error),
TapSetOffload(Error),
TapSetVnetHdrSize(Error),
TapValidate(String),
WaitContextDisableTap(Error),
WaitContextEnableTap(Error),
WaitError(Error),
WriteAck(Error),
WriteBuffer(Error),
}Variants
CloneKillEvent(Error)
Cloning kill event failed.
CreateKillEvent(Error)
Creating kill event failed.
CreateWaitContext(Error)
Creating WaitContext failed.
EventAddTap(Error)
Adding the tap descriptor back to the event context failed.
EventRemoveTap(Error)
Removing the tap descriptor from the event context failed.
InvalidCmd
Invalid control command
ReadCtrlData(Error)
Error reading data from control queue.
ReadCtrlHeader(Error)
Error reading header from control queue.
RxDescriptorsExhausted
There are no more available descriptors to receive into.
TapEnable(Error)
Enabling tap interface failed.
TapGetMtu(Error)
Couldn’t get the MTU from the tap device.
TapOpen(Error)
Open tap device failed.
TapSetIp(Error)
Setting tap IP failed.
TapSetMacAddress(Error)
Setting tap mac address failed.
TapSetNetmask(Error)
Setting tap netmask failed.
TapSetOffload(Error)
Setting tap offload failed.
TapSetVnetHdrSize(Error)
Setting vnet header size failed.
TapValidate(String)
Validating tap interface failed.
WaitContextDisableTap(Error)
Removing read event from the tap fd events failed.
WaitContextEnableTap(Error)
Adding read event to the tap fd events failed.
WaitError(Error)
Error while waiting for events.
WriteAck(Error)
Failed writing an ack in response to a control message.
WriteBuffer(Error)
Writing to a buffer in the guest failed.