pub struct PendingBuffer {
pub buffer: Box<[u8; 65562]>,
pub length: u32,
}Fields
buffer: Box<[u8; 65562]>According to virtio-spec, the maximum incoming packet will be to 65550 bytes long (the maximum size of a TCP or UDP packet, plus the 14 byte ethernet header) The 12byte struct virtio_net_hdr is prepended to this, therefore making it for 65562
length: u32Implementations
Sourceimpl PendingBuffer
impl PendingBuffer