pub enum P9Error {
CreateServer(Error),
CreateWaitContext(Error),
Internal(Error),
NoReadableDescriptors,
NoWritableDescriptors,
ReadQueueEvent(Error),
SignalUsedQueue(Error),
TagTooLong(usize),
WaitError(Error),
}Expand description
Errors that occur during operation of a virtio 9P device.
Variants
CreateServer(Error)
Failed to create a 9p server.
CreateWaitContext(Error)
Creating WaitContext failed.
Internal(Error)
An internal I/O error occurred.
NoReadableDescriptors
A request is missing readable descriptors.
NoWritableDescriptors
A request is missing writable descriptors.
ReadQueueEvent(Error)
Error while reading from the virtio queue’s Event.
SignalUsedQueue(Error)
Failed to signal the virio used queue.
TagTooLong(usize)
The tag for the 9P device was too large to fit in the config space.
WaitError(Error)
Error while polling for events.