enum PvClockWorkerState {
Idle(Tube),
Stub(WorkerThread<StubWorkerReturn>),
Main(WorkerThread<MainWorkerReturn>),
None,
}Expand description
An enum to keep dynamic state of pvclock workers in a type safe manner.
Variants
Idle(Tube)
Idle means no worker is running. This tube is for communicating with this device from the crosvm threads.
Stub(WorkerThread<StubWorkerReturn>)
A stub worker to respond pvclock commands when the device is not activated yet.
Main(WorkerThread<MainWorkerReturn>)
A main worker to respond pvclock commands while the device is active.
None
None is used only for handling transitional state between the states above.