struct PvClockState {
tsc_frequency: u64,
paused_main_worker: Option<PvClockWorkerSnapshot>,
total_suspend_ns: Arc<AtomicU64>,
features: u64,
acked_features: u64,
}Expand description
Serializable part of the PvClock struct which will be used by the virtio_snapshot / restore.
Fields
tsc_frequency: u64paused_main_worker: Option<PvClockWorkerSnapshot>If the device is sleeping, a PvClockWorkerSnapshot that can re-create the worker will be stored here. (We can’t just store the worker itself as it contains an object tree with references to GuestMemory.)
total_suspend_ns: Arc<AtomicU64>The total time the vm has been suspended, this is in an Arc<AtomicU64>> because it’s set
by the PvClockWorker thread but read by PvClock from the mmio bus in the main thread.
features: u64acked_features: u64Trait Implementations
Sourceimpl<'de> Deserialize<'de> for PvClockState
impl<'de> Deserialize<'de> for PvClockState
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more