Struct PeekedDescriptorChain

pub struct PeekedDescriptorChain<'q> {
    queue: &'q mut Queue,
    desc_chain: DescriptorChain,
}
A DescriptorChain that has been peeked from a Queue but not popped yet.

Call pop() to pop this descriptor chain from the Queue and receive the contained DescriptorChain object.

This object holds a mutable reference to the Queue to ensure it is not possible to pop or peek another descriptor while a peek is already active. Either pop() or drop this object before attempting to manipulate the Queue again.

Fields

queue: &'q mut Queuedesc_chain: DescriptorChain

Implementations

Source

impl<'q> PeekedDescriptorChain<'q>

fn new(queue: &'q mut Queue, desc_chain: DescriptorChain) -> Self

Create a PeekedDescriptorChain that holds a mutable reference to its Queue. Use Queue::peek() rather than calling this function.

pub fn pop(self) -> DescriptorChain

Pop this descriptor chain from the queue.

Methods from Deref<Target = DescriptorChain>

pub fn mem(&self) -> &GuestMemory

Returns a reference to the GuestMemory instance.

pub fn index(&self) -> u16

Returns the index of the first descriptor in the chain.