Struct Sense

pub struct Sense {
    pub key: u8,
    pub asc: u8,
    pub ascq: u8,
}
Sense code representation

Fields

key: u8

Provides generic information describing an error or exception condition.

asc: u8

Additional Sense Code. Indicates further information related to the error or exception reported in the key field.

ascq: u8

Additional Sense Code Qualifier. Indicates further detailed information related to the additional sense code.

Implementations

Source

impl Sense

fn write_to( &self, writer: &mut Writer, sense_size: u32, ) -> Result<(), ExecuteError>