Struct Parameters

pub struct Parameters {
Show 14 fields pub capture: bool, pub num_output_devices: u32, pub num_input_devices: u32, pub backend: StreamSourceBackend, pub num_output_streams: u32, pub num_input_streams: u32, pub playback_path: String, pub playback_size: usize, pub client_type: CrasClientType, pub socket_type: CrasSocketType, pub output_device_config: Vec<PCMDeviceParameters>, pub input_device_config: Vec<PCMDeviceParameters>, pub card_index: usize, pub unmap_guest_memory_on_fork: bool,
}
Holds the parameters for a cras sound device

Fields

capture: boolnum_output_devices: u32num_input_devices: u32backend: StreamSourceBackendnum_output_streams: u32num_input_streams: u32playback_path: Stringplayback_size: usizeclient_type: CrasClientTypesocket_type: CrasSocketTypeoutput_device_config: Vec<PCMDeviceParameters>input_device_config: Vec<PCMDeviceParameters>card_index: usizeunmap_guest_memory_on_fork: bool

set MADV_DONTFORK on guest memory

Intended for use in combination with protected VMs, where the guest memory can be dangerous to access. Some systems, e.g. Android, have tools that fork processes and examine their memory. This flag effectively hides the guest memory from those tools.

Not compatible with sandboxing.

Implementations

Source

impl Parameters

pub(crate) fn get_total_output_streams(&self) -> u32

pub(crate) fn get_total_input_streams(&self) -> u32

pub(crate) fn get_total_streams(&self) -> u32

pub(crate) fn get_device_params( &self, pcm_info: &virtio_snd_pcm_info, ) -> Result<PCMDeviceParameters, Error>