pub struct PeekedDescriptorChain<'q> {
queue: &'q mut Queue,
desc_chain: DescriptorChain,
}Expand description
A DescriptorChain that has been peeked from a Queue but not popped yet.
Call pop() to pop this descriptor chain from the Queue and receive the
contained DescriptorChain object.
This object holds a mutable reference to the Queue to ensure it is not possible to pop or peek
another descriptor while a peek is already active. Either pop() or drop this object before
attempting to manipulate the Queue again.
Fields
queue: &'q mut Queuedesc_chain: DescriptorChainImplementations
Sourceimpl<'q> PeekedDescriptorChain<'q>
impl<'q> PeekedDescriptorChain<'q>
Sourcefn new(queue: &'q mut Queue, desc_chain: DescriptorChain) -> Self
fn new(queue: &'q mut Queue, desc_chain: DescriptorChain) -> Self
Create a PeekedDescriptorChain that holds a mutable reference to its Queue.
Use Queue::peek() rather than calling this function.
Sourcepub fn pop(self) -> DescriptorChain
pub fn pop(self) -> DescriptorChain
Pop this descriptor chain from the queue.
Methods from Deref<Target = DescriptorChain>
Sourcepub fn mem(&self) -> &GuestMemory
pub fn mem(&self) -> &GuestMemory
Returns a reference to the GuestMemory instance.