async fn run_with_handler(
listener: SocketListener,
handler: Box<dyn Backend>,
ex: &Executor,
) -> Result<()>Expand description
Attaches to an already bound socket via listener and handles incoming messages from the
VMM, which are dispatched to the device backend via the VhostUserDevice trait methods.