pub struct VhostUserConsoleDevice {
console: ConsoleDevice,
raw_stdin: bool,
}Expand description
Console device for use with vhost-user. Will set stdin back to canon mode if we are getting input from it.
Fields
console: ConsoleDeviceraw_stdin: boolWhether we should set stdin to raw mode because we are getting user input from there.