pub struct VhostUserParams<T: Debug> {
pub vhost: String,
pub device: T,
}Expand description
Extends any device configuration with a mandatory extra “vhost” parameter to specify the socket or PCI device to use in order to communicate with a vhost client.
The vhost argument must come first, followed by all the arguments required by device.
Fields
vhost: Stringdevice: TTrait Implementations
Sourceimpl<'de, T> Deserialize<'de> for VhostUserParams<T>where
T: Deserialize<'de> + Debug,
impl<'de, T> Deserialize<'de> for VhostUserParams<T>where
T: Deserialize<'de> + Debug,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<T> FromArgValue for VhostUserParams<T>where
T: Debug + for<'de> Deserialize<'de>,
impl<T> FromArgValue for VhostUserParams<T>where
T: Debug + for<'de> Deserialize<'de>,