Struct VhostUserVsockDevice

pub struct VhostUserVsockDevice {
    cid: u64,
    handle: Vsock,
}
A vhost-vsock device which handle is already opened. This allows the parent process to open the vhost-vsock device, create this structure, and pass it to the child process so it doesn’t need the rights to open the vhost-vsock device itself.

Fields

cid: u64handle: Vsock

Implementations

Source

impl VhostUserVsockDevice

pub fn new<P: AsRef<Path>>(cid: u64, vhost_device: P) -> Result<Self>