pub enum Error {
Show 38 variants
CopyConfig(Error),
CreateBackendReqHandler(Error),
CreateEvent(Error),
GetConfig(Error),
GetFeatures(Error),
GetHostAddress(GuestMemoryError),
GetProtocolFeatures(Error),
GetQueueNum(Error),
GetVringBase(Error),
MsixConfigUnavailable,
MsixIrqfdUnavailable,
ProtocolFeatureNotNegoiated(VhostUserProtocolFeatures),
ResetOwner(Error),
Restore(Error),
SerdeValueToSlice(Error),
SetConfig(Error),
SetDeviceRequestChannel(Error),
SetFeatures(Error),
SetMemTable(Error),
SetOwner(Error),
SetProtocolFeatures(Error),
SetVringAddr(Error),
SetVringBase(Error),
SetVringCall(Error),
SetVringEnable(Error),
SetVringKick(Error),
SetVringNum(Error),
ShmemRegions(Error),
Sleep(Error),
SliceToSerdeValue(Error),
Snapshot(Error),
SocketConnect(Error),
SpawnWorker(Error),
TagTooLong {
len: usize,
max: usize,
},
TooManyShmemRegions(usize),
VringBaseTooBig(u32),
Wake(Error),
WakeWorker,
}Variants
CopyConfig(Error)
Failed to copy config to a buffer.
CreateBackendReqHandler(Error)
Failed to create backend request handler
CreateEvent(Error)
Failed to create base::Event.
GetConfig(Error)
Failed to get config.
GetFeatures(Error)
Failed to get features.
GetHostAddress(GuestMemoryError)
Failed to get host address.
GetProtocolFeatures(Error)
Failed to get protocol features.
GetQueueNum(Error)
Failed to get number of queues.
GetVringBase(Error)
Failed to get vring base offset.
MSI-X config is unavailable.
MSI-X irqfd is unavailable.
ProtocolFeatureNotNegoiated(VhostUserProtocolFeatures)
ResetOwner(Error)
Failed to reset owner.
Restore(Error)
Failed to restore.
SerdeValueToSlice(Error)
Failed to convert serde Value to a slice.
SetConfig(Error)
Failed to set config.
SetDeviceRequestChannel(Error)
Failed to set device request channel.
SetFeatures(Error)
Failed to set features.
SetMemTable(Error)
Failed to set memory map regions.
SetOwner(Error)
Failed to set owner.
SetProtocolFeatures(Error)
Failed to set protocol features.
SetVringAddr(Error)
Failed to set vring address.
SetVringBase(Error)
Failed to set vring base offset.
SetVringCall(Error)
Failed to set eventfd to signal used vring buffers.
SetVringEnable(Error)
Failed to enable or disable vring.
SetVringKick(Error)
Failed to set eventfd for adding buffers to vring.
SetVringNum(Error)
Failed to set the size of the queue.
ShmemRegions(Error)
Error getting the shmem regions.
Sleep(Error)
Failed to sleep the device.
SliceToSerdeValue(Error)
Failed to convert a slice to a serde Value.
Snapshot(Error)
Failed to snapshot.
SocketConnect(Error)
Failed to connect socket.
SpawnWorker(Error)
Failed to spawn worker thread.
TagTooLong
The tag for the Fs device was too long to fit in the config space.
TooManyShmemRegions(usize)
Too many shmem regions.
VringBaseTooBig(u32)
vring base from vhost-user backend is too big.
Wake(Error)
failed to wake the vhost user device.
WakeWorker
failed to wake the worker.