Struct AsyncCmdDescMap

pub struct AsyncCmdDescMap(BTreeMap<AsyncCmdTag, DescriptorChain>);
AsyncCmdDescMap is a BTreeMap which stores descriptor chains in which asynchronous responses will be written.

Tuple Fields

0: BTreeMap<AsyncCmdTag, DescriptorChain>

Implementations

Source

impl AsyncCmdDescMap

pub fn insert(&mut self, tag: AsyncCmdTag, descriptor_chain: DescriptorChain)

pub fn remove(&mut self, tag: &AsyncCmdTag) -> Option<DescriptorChain>

pub fn create_cancellation_responses( &self, target_stream_id: &u32, target_queue_type: Option<QueueType>, processing_tag: Option<AsyncCmdTag>, ) -> Vec<AsyncCmdResponse>

Returns a list of AsyncCmdResponses to cancel pending commands that target stream target_stream_id. If target_queue_type is specified, then only create the requests for the specified queue. Otherwise, create the requests for both input and output queue. If processing_tag is specified, a cancellation request for that tag will not be created.