pub enum VideoCmd {
Show 13 variants
QueryCapability {
queue_type: QueueType,
},
StreamCreate {
stream_id: u32,
coded_format: Format,
input_resource_type: ResourceType,
output_resource_type: ResourceType,
},
StreamDestroy {
stream_id: u32,
},
StreamDrain {
stream_id: u32,
},
ResourceCreate {
stream_id: u32,
queue_type: QueueType,
resource_id: u32,
plane_offsets: Vec<u32>,
plane_entries: Vec<Vec<UnresolvedResourceEntry>>,
},
ResourceQueue {
stream_id: u32,
queue_type: QueueType,
resource_id: u32,
timestamp: u64,
data_sizes: Vec<u32>,
},
ResourceDestroyAll {
stream_id: u32,
queue_type: QueueType,
},
QueueClear {
stream_id: u32,
queue_type: QueueType,
},
GetParams {
stream_id: u32,
queue_type: QueueType,
is_ext: bool,
},
SetParams {
stream_id: u32,
queue_type: QueueType,
params: Params,
is_ext: bool,
},
QueryControl {
query_ctrl_type: QueryCtrlType,
},
GetControl {
stream_id: u32,
ctrl_type: CtrlType,
},
SetControl {
stream_id: u32,
ctrl_val: CtrlVal,
},
}Variants
QueryCapability
StreamCreate
StreamDestroy
StreamDrain
ResourceCreate
Fields

plane_entries: Vec<Vec<UnresolvedResourceEntry>>The outer vector contains one entry per memory plane, whereas the inner vector contains all the memory entries that make a single plane (i.e. one for virtio objects, one or more for guest pages).
ResourceQueue
ResourceDestroyAll
QueueClear
GetParams
Fields
SetParams
Fields
QueryControl
Fields

query_ctrl_type: QueryCtrlTypeGetControl
SetControl
Implementations
Sourceimpl VideoCmd
impl VideoCmd
Sourcepub fn from_reader(r: &mut Reader) -> Result<Self, ReadCmdError>
pub fn from_reader(r: &mut Reader) -> Result<Self, ReadCmdError>
Reads a request on virtqueue and construct a VideoCmd value.