Enum SessionState

enum SessionState {
    AwaitingInitialResolution,
    AwaitingBufferCount,
    Decoding {
        output_queue: OutputQueue,
        format_converter: SwConverter,
    },
    Drc,
}
A crosvm decoder needs to go through a number if setup stages before being able to decode, and can require some setup to be redone when a dynamic resolution change occurs. This enum ensures that the data associated with a given state only exists when we actually are in this state.

Variants



AwaitingInitialResolution

Waiting for libavcodec to tell us the resolution of the stream.



AwaitingBufferCount

Waiting for the client to call set_output_buffer_count.



Decoding

Decoding and producing frames.

Fields

output_queue: OutputQueue
format_converter: SwConverter


Drc

Dynamic Resolution Change - we can still accept buffers in the old format, but are waiting for new parameters before doing any decoding.