struct GenericDecoderBackend<S: DecoderBackend>(pub S);Expand description
Type that changes the Session associated type to Box<dyn DecoderSession>, allowing us to
use trait objects for backends.
Tuple Fields
0: STrait Implementations
Sourceimpl<S> DecoderBackend for GenericDecoderBackend<S>
impl<S> DecoderBackend for GenericDecoderBackend<S>
type Session = Box<dyn DecoderSession>
Sourcefn get_capabilities(&self) -> Capability
fn get_capabilities(&self) -> Capability
Return the decoding capabilities for this backend instance.
Sourcefn new_session(&mut self, format: Format) -> Result<Self::Session, VideoError>
fn new_session(&mut self, format: Format) -> Result<Self::Session, VideoError>
Create a new decoding session for the passed
format.Sourcefn into_trait_object(
self,
) -> Box<dyn DecoderBackend<Session = Box<dyn DecoderSession>>>where
Self: Sized + 'static,
fn into_trait_object(
self,
) -> Box<dyn DecoderBackend<Session = Box<dyn DecoderSession>>>where
Self: Sized + 'static,
Turn this backend into a trait object, allowing the same decoder to operate on a set of
different backends.