Enum BorrowedFrame

enum BorrowedFrame {
    Decoded(Box<dyn DecodedHandle<Descriptor = BufferDescWithPicId>>),
    Held(Box<dyn AsRef<BufferDescWithPicId>>),
}
A frame that is currently not available for being decoded into, either because it has been decoded and is waiting for us to release it (Decoded), or because we temporarily removed it from the decoder pool after a reset and are waiting for the client to tell us we can use it (Held).

Variants



Decoded(Box<dyn DecodedHandle<Descriptor = BufferDescWithPicId>>)



Held(Box<dyn AsRef<BufferDescWithPicId>>)