enum OutputQueueState {
AwaitingBufferCount,
Decoding,
Drc,
}Expand description
The state for the output queue containing the buffers that will receive the decoded data.
Variants
AwaitingBufferCount
Waiting for the client to call set_output_buffer_count.
Decoding
Codec is capable of decoding frames.
Drc
Dynamic Resolution Change - we can still accept buffers in the old format, but are waiting for new parameters before doing any decoding.