Struct GuestMemDescriptor

struct GuestMemDescriptor(GuestMemHandle);
A guest memory descriptor that uses a managed buffer as a shadow that will be copied into the guest memory once decoding is over.

Tuple Fields

0: GuestMemHandle