Enum VideoCmdResponseType

pub enum VideoCmdResponseType {
    Sync(CmdResponse),
    Async(AsyncCmdTag),
}
A return value when a command from the guest is processed.

Variants



Sync(CmdResponse)

The response for a synchronous command. This can be returned to the guest immediately via command virtqueue.



Async(AsyncCmdTag)

The tag for an asynchronous command that the back-end device will complete. Once the command is completed, its result will be sent with the same tag. This can be seen as a poor man’s future pattern.