pub enum Error {
CloneDescriptorFailed(Error),
DescriptorNotAvailable,
DeviceCreationFailed(String),
EventAsyncCreationFailed(AsyncError),
ReadFailure(ReadCmdError),
WaitContextCreationFailed(Error),
WaitError(Error),
WriteEventFailure {
event: VideoEvt,
error: Error,
},
}Expand description
An error indicating something went wrong in virtio-video’s worker.
Variants
CloneDescriptorFailed(Error)
Cloning a descriptor failed
DescriptorNotAvailable
No available descriptor in which an event is written to.
DeviceCreationFailed(String)
Creating a video device failed.
EventAsyncCreationFailed(AsyncError)
Making an EventAsync failed.
ReadFailure(ReadCmdError)
Failed to read a virtio-video command.
WaitContextCreationFailed(Error)
Creating WaitContext failed.
WaitError(Error)
Error while polling for events.
WriteEventFailure
Failed to write an event into the event queue.