Struct EventQueue

pub struct EventQueue<T> {
    event: Event,
    pending_events: VecDeque<T>,
}
Manages a pollable queue of events to be sent to the decoder or encoder.

Fields

event: Event

Pipe used to signal available events.

pending_events: VecDeque<T>

FIFO of all pending events.

Implementations

Source

impl<T> EventQueue<T>

pub fn new() -> Result<Self>

Create a new event queue.

pub fn queue_event(&mut self, event: T) -> Result<()>

Add event to the queue.

pub fn dequeue_event(&mut self) -> Result<T>

Read the next event, blocking until an event becomes available.

pub fn retain<P: FnMut(&T) -> bool>(&mut self, predicate: P)

Remove all the posted events for which predicate returns false.