struct SimpleAllocator {
current_address: u64,
}Expand description
A simple allocator that can allocate non-overlapping aligned intervals.
The addresses allocated are not exclusively reserved for the device, and cannot be used for a static device. The allocated placeholder address describes the layout of PCI BAR for hotplugged devices. Actual memory allocation is handled by PCI BAR reprogramming initiated by guest OS.
Fields
current_address: u64Implementations