pub enum DeviceProvider {
Created {
control_tube: Mutex<Tube>,
},
Started {
inner: Arc<ProviderInner>,
},
Failed,
}Expand description
Device provider is an xhci backend device provider that provides generic semantics to handle various types of backend devices and connects them to the xhci layer.
Variants
Implementations
Sourceimpl DeviceProvider
impl DeviceProvider
pub fn new() -> Result<(Tube, DeviceProvider)>
fn start_helper( &mut self, fail_handle: Arc<dyn FailHandle>, event_loop: Arc<EventLoop>, hub: Arc<UsbHub>, ) -> Result<()>