pub struct ScatterGatherBuffer {
mem: GuestMemory,
td: TransferDescriptor,
}Expand description
See xHCI spec 3.2.8 for scatter/gather transfer. It’s used in bulk/interrupt transfers. See 3.2.10 for details.
Fields
mem: GuestMemorytd: TransferDescriptorImplementations
Sourceimpl ScatterGatherBuffer
impl ScatterGatherBuffer
Sourcepub fn new(
mem: GuestMemory,
td: TransferDescriptor,
) -> Result<ScatterGatherBuffer, Error>
pub fn new( mem: GuestMemory, td: TransferDescriptor, ) -> Result<ScatterGatherBuffer, Error>
Create a new buffer from transfer descriptor.
pub fn is_empty(&self) -> Result<bool, Error>
Sourcefn get_trb_data(
&self,
atrb: &AddressedTrb,
) -> Result<(GuestAddress, usize), Error>
fn get_trb_data( &self, atrb: &AddressedTrb, ) -> Result<(GuestAddress, usize), Error>
Get the guest address and length of the TRB’s data buffer. This is usually a separate buffer pointed to by the TRB, but it can also be within the TRB itself in the case of immediate data.