pub enum DescriptorAccess {
DeviceRead,
DeviceWrite,
}Expand description
Type of access allowed for a single virtio descriptor within a descriptor chain.
Variants
DeviceRead
Descriptor is readable by the device (written by the driver before putting the descriptor chain on the available queue).
DeviceWrite
Descriptor is writable by the device (read by the driver after the device puts the descriptor chain on the used queue).