pub enum DisplayBackend {
Wayland(Option<PathBuf>),
X(Option<String>),
Stub,
Android(String),
}Expand description
Indicates a backend that should be tried for the gpu to use for display.
Several instances of this enum are used in an ordered list to give the gpu device many backends to use as fallbacks in case some do not work.
Variants
Wayland(Option<PathBuf>)
Use the wayland backend with the given socket path if given.
X(Option<String>)
Open a connection to the X server at the given display if given.
Stub
Emulate a display without actually displaying it.
Android(String)
The display buffer is backed by an Android surface. The surface is set via an AIDL service that the backend hosts. Currently, the AIDL service is registered to the service manager using the name given here. The entity holding the surface is expected to locate the service via this name, and pass the surface to it.
Implementations
Sourceimpl DisplayBackend
impl DisplayBackend
fn build(&self) -> Result<GpuDisplay, GpuDisplayError>