pub struct Sense {
pub key: u8,
pub asc: u8,
pub ascq: u8,
}Expand description
Sense code representation
Fields
key: u8Provides generic information describing an error or exception condition.
asc: u8Additional Sense Code. Indicates further information related to the error or exception reported in the key field.
ascq: u8Additional Sense Code Qualifier. Indicates further detailed information related to the additional sense code.
Implementations